@@ -19,6 +19,8 @@
 
 #pragma once
 
+#include <glib.h>
+
 /**
  * SECTION: version
  * @section_id: version-macros
@@ -36,7 +38,7 @@
  *
  * Since: 0.10.0
  */
-#define GARROW_VERSION_MAJOR (16)
+#define GARROW_VERSION_MAJOR (17)
 
 /**
  * GARROW_VERSION_MINOR:
@@ -45,7 +47,7 @@
  *
  * Since: 0.10.0
  */
-#define GARROW_VERSION_MINOR (1)
+#define GARROW_VERSION_MINOR (0)
 
 /**
  * GARROW_VERSION_MICRO:
@@ -108,6 +110,15 @@
 #  define GARROW_UNAVAILABLE(major, minor) G_UNAVAILABLE(major, minor)
 #endif
 
+/**
+ * GARROW_VERSION_17_0:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 17.0.0
+ */
+#define GARROW_VERSION_17_0 G_ENCODE_VERSION(17, 0)
+
 /**
  * GARROW_VERSION_16_0:
  *
@@ -306,6 +317,15 @@
  */
 #define GARROW_VERSION_0_12 G_ENCODE_VERSION(0, 12)
 
+/**
+ * GARROW_VERSION_0_11:
+ *
+ * You can use this macro value for compile time API version check.
+ *
+ * Since: 0.11.0
+ */
+#define GARROW_VERSION_0_11 G_ENCODE_VERSION(0, 11)
+
 /**
  * GARROW_VERSION_0_10:
  *
@@ -359,231 +379,260 @@
   G_ENCODE_VERSION(GARROW_VERSION_MAJOR, GARROW_VERSION_MINOR)
 #endif
 
+#if (defined(_WIN32) || defined(__CYGWIN__)) && defined(_MSC_VER) &&   !defined(GARROW_STATIC_COMPILATION)
+#  define GARROW_EXPORT __declspec(dllexport)
+#  define GARROW_IMPORT __declspec(dllimport)
+#else
+#  define GARROW_EXPORT
+#  define GARROW_IMPORT
+#endif
 
-#define GARROW_AVAILABLE_IN_ALL
+#ifdef GARROW_COMPILATION
+#  define GARROW_API GARROW_EXPORT
+#else
+#  define GARROW_API GARROW_IMPORT
+#endif
+
+#define GARROW_EXTERN GARROW_API extern
+
+#define GARROW_AVAILABLE_IN_ALL GARROW_EXTERN
+
+#if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_17_0
+#  define GARROW_DEPRECATED_IN_17_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_17_0_FOR(function) GARROW_DEPRECATED_FOR(function)
+#else
+#  define GARROW_DEPRECATED_IN_17_0
+#  define GARROW_DEPRECATED_IN_17_0_FOR(function)
+#endif
+
+#if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_17_0
+#  define GARROW_AVAILABLE_IN_17_0 GARROW_EXTERN GARROW_UNAVAILABLE(17, 0)
+#else
+#  define GARROW_AVAILABLE_IN_17_0 GARROW_EXTERN
+#endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_16_0
-#  define GARROW_DEPRECATED_IN_16_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_16_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_16_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_16_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_16_0
 #  define GARROW_DEPRECATED_IN_16_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_16_0
-#  define GARROW_AVAILABLE_IN_16_0 GARROW_UNAVAILABLE(16, 0)
+#  define GARROW_AVAILABLE_IN_16_0 GARROW_EXTERN GARROW_UNAVAILABLE(16, 0)
 #else
-#  define GARROW_AVAILABLE_IN_16_0
+#  define GARROW_AVAILABLE_IN_16_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_15_0
-#  define GARROW_DEPRECATED_IN_15_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_15_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_15_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_15_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_15_0
 #  define GARROW_DEPRECATED_IN_15_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_15_0
-#  define GARROW_AVAILABLE_IN_15_0 GARROW_UNAVAILABLE(15, 0)
+#  define GARROW_AVAILABLE_IN_15_0 GARROW_EXTERN GARROW_UNAVAILABLE(15, 0)
 #else
-#  define GARROW_AVAILABLE_IN_15_0
+#  define GARROW_AVAILABLE_IN_15_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_14_0
-#  define GARROW_DEPRECATED_IN_14_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_14_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_14_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_14_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_14_0
 #  define GARROW_DEPRECATED_IN_14_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_14_0
-#  define GARROW_AVAILABLE_IN_14_0 GARROW_UNAVAILABLE(14, 0)
+#  define GARROW_AVAILABLE_IN_14_0 GARROW_EXTERN GARROW_UNAVAILABLE(14, 0)
 #else
-#  define GARROW_AVAILABLE_IN_14_0
+#  define GARROW_AVAILABLE_IN_14_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_13_0
-#  define GARROW_DEPRECATED_IN_13_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_13_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_13_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_13_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_13_0
 #  define GARROW_DEPRECATED_IN_13_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_13_0
-#  define GARROW_AVAILABLE_IN_13_0 GARROW_UNAVAILABLE(13, 0)
+#  define GARROW_AVAILABLE_IN_13_0 GARROW_EXTERN GARROW_UNAVAILABLE(13, 0)
 #else
-#  define GARROW_AVAILABLE_IN_13_0
+#  define GARROW_AVAILABLE_IN_13_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_12_0
-#  define GARROW_DEPRECATED_IN_12_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_12_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_12_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_12_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_12_0
 #  define GARROW_DEPRECATED_IN_12_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_12_0
-#  define GARROW_AVAILABLE_IN_12_0 GARROW_UNAVAILABLE(12, 0)
+#  define GARROW_AVAILABLE_IN_12_0 GARROW_EXTERN GARROW_UNAVAILABLE(12, 0)
 #else
-#  define GARROW_AVAILABLE_IN_12_0
+#  define GARROW_AVAILABLE_IN_12_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_11_0
-#  define GARROW_DEPRECATED_IN_11_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_11_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_11_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_11_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_11_0
 #  define GARROW_DEPRECATED_IN_11_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_11_0
-#  define GARROW_AVAILABLE_IN_11_0 GARROW_UNAVAILABLE(11, 0)
+#  define GARROW_AVAILABLE_IN_11_0 GARROW_EXTERN GARROW_UNAVAILABLE(11, 0)
 #else
-#  define GARROW_AVAILABLE_IN_11_0
+#  define GARROW_AVAILABLE_IN_11_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_10_0
-#  define GARROW_DEPRECATED_IN_10_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_10_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_10_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_10_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_10_0
 #  define GARROW_DEPRECATED_IN_10_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_10_0
-#  define GARROW_AVAILABLE_IN_10_0 GARROW_UNAVAILABLE(10, 0)
+#  define GARROW_AVAILABLE_IN_10_0 GARROW_EXTERN GARROW_UNAVAILABLE(10, 0)
 #else
-#  define GARROW_AVAILABLE_IN_10_0
+#  define GARROW_AVAILABLE_IN_10_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_9_0
-#  define GARROW_DEPRECATED_IN_9_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_9_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_9_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_9_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_9_0
 #  define GARROW_DEPRECATED_IN_9_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_9_0
-#  define GARROW_AVAILABLE_IN_9_0 GARROW_UNAVAILABLE(9, 0)
+#  define GARROW_AVAILABLE_IN_9_0 GARROW_EXTERN GARROW_UNAVAILABLE(9, 0)
 #else
-#  define GARROW_AVAILABLE_IN_9_0
+#  define GARROW_AVAILABLE_IN_9_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_8_0
-#  define GARROW_DEPRECATED_IN_8_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_8_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_8_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_8_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_8_0
 #  define GARROW_DEPRECATED_IN_8_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_8_0
-#  define GARROW_AVAILABLE_IN_8_0 GARROW_UNAVAILABLE(8, 0)
+#  define GARROW_AVAILABLE_IN_8_0 GARROW_EXTERN GARROW_UNAVAILABLE(8, 0)
 #else
-#  define GARROW_AVAILABLE_IN_8_0
+#  define GARROW_AVAILABLE_IN_8_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_7_0
-#  define GARROW_DEPRECATED_IN_7_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_7_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_7_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_7_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_7_0
 #  define GARROW_DEPRECATED_IN_7_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_7_0
-#  define GARROW_AVAILABLE_IN_7_0 GARROW_UNAVAILABLE(7, 0)
+#  define GARROW_AVAILABLE_IN_7_0 GARROW_EXTERN GARROW_UNAVAILABLE(7, 0)
 #else
-#  define GARROW_AVAILABLE_IN_7_0
+#  define GARROW_AVAILABLE_IN_7_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_6_0
-#  define GARROW_DEPRECATED_IN_6_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_6_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_6_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_6_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_6_0
 #  define GARROW_DEPRECATED_IN_6_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_6_0
-#  define GARROW_AVAILABLE_IN_6_0 GARROW_UNAVAILABLE(6, 0)
+#  define GARROW_AVAILABLE_IN_6_0 GARROW_EXTERN GARROW_UNAVAILABLE(6, 0)
 #else
-#  define GARROW_AVAILABLE_IN_6_0
+#  define GARROW_AVAILABLE_IN_6_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_5_0
-#  define GARROW_DEPRECATED_IN_5_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_5_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_5_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_5_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_5_0
 #  define GARROW_DEPRECATED_IN_5_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_5_0
-#  define GARROW_AVAILABLE_IN_5_0 GARROW_UNAVAILABLE(5, 0)
+#  define GARROW_AVAILABLE_IN_5_0 GARROW_EXTERN GARROW_UNAVAILABLE(5, 0)
 #else
-#  define GARROW_AVAILABLE_IN_5_0
+#  define GARROW_AVAILABLE_IN_5_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_4_0
-#  define GARROW_DEPRECATED_IN_4_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_4_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_4_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_4_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_4_0
 #  define GARROW_DEPRECATED_IN_4_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_4_0
-#  define GARROW_AVAILABLE_IN_4_0 GARROW_UNAVAILABLE(4, 0)
+#  define GARROW_AVAILABLE_IN_4_0 GARROW_EXTERN GARROW_UNAVAILABLE(4, 0)
 #else
-#  define GARROW_AVAILABLE_IN_4_0
+#  define GARROW_AVAILABLE_IN_4_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_3_0
-#  define GARROW_DEPRECATED_IN_3_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_3_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_3_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_3_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_3_0
 #  define GARROW_DEPRECATED_IN_3_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_3_0
-#  define GARROW_AVAILABLE_IN_3_0 GARROW_UNAVAILABLE(3, 0)
+#  define GARROW_AVAILABLE_IN_3_0 GARROW_EXTERN GARROW_UNAVAILABLE(3, 0)
 #else
-#  define GARROW_AVAILABLE_IN_3_0
+#  define GARROW_AVAILABLE_IN_3_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_2_0
-#  define GARROW_DEPRECATED_IN_2_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_2_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_2_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_2_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_2_0
 #  define GARROW_DEPRECATED_IN_2_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_2_0
-#  define GARROW_AVAILABLE_IN_2_0 GARROW_UNAVAILABLE(2, 0)
+#  define GARROW_AVAILABLE_IN_2_0 GARROW_EXTERN GARROW_UNAVAILABLE(2, 0)
 #else
-#  define GARROW_AVAILABLE_IN_2_0
+#  define GARROW_AVAILABLE_IN_2_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_1_0
-#  define GARROW_DEPRECATED_IN_1_0                GARROW_DEPRECATED
-#  define GARROW_DEPRECATED_IN_1_0_FOR(function)  GARROW_DEPRECATED_FOR(function)
+#  define GARROW_DEPRECATED_IN_1_0               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_1_0_FOR(function) GARROW_DEPRECATED_FOR(function)
 #else
 #  define GARROW_DEPRECATED_IN_1_0
 #  define GARROW_DEPRECATED_IN_1_0_FOR(function)
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_1_0
-#  define GARROW_AVAILABLE_IN_1_0 GARROW_UNAVAILABLE(1, 0)
+#  define GARROW_AVAILABLE_IN_1_0 GARROW_EXTERN GARROW_UNAVAILABLE(1, 0)
 #else
-#  define GARROW_AVAILABLE_IN_1_0
+#  define GARROW_AVAILABLE_IN_1_0 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_0_17
@@ -595,9 +644,9 @@
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_0_17
-#  define GARROW_AVAILABLE_IN_0_17 GARROW_UNAVAILABLE(0, 17)
+#  define GARROW_AVAILABLE_IN_0_17 GARROW_EXTERN GARROW_UNAVAILABLE(0, 17)
 #else
-#  define GARROW_AVAILABLE_IN_0_17
+#  define GARROW_AVAILABLE_IN_0_17 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_0_16
@@ -609,9 +658,9 @@
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_0_16
-#  define GARROW_AVAILABLE_IN_0_16 GARROW_UNAVAILABLE(0, 16)
+#  define GARROW_AVAILABLE_IN_0_16 GARROW_EXTERN GARROW_UNAVAILABLE(0, 16)
 #else
-#  define GARROW_AVAILABLE_IN_0_16
+#  define GARROW_AVAILABLE_IN_0_16 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_0_15
@@ -623,9 +672,9 @@
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_0_15
-#  define GARROW_AVAILABLE_IN_0_15 GARROW_UNAVAILABLE(0, 15)
+#  define GARROW_AVAILABLE_IN_0_15 GARROW_EXTERN GARROW_UNAVAILABLE(0, 15)
 #else
-#  define GARROW_AVAILABLE_IN_0_15
+#  define GARROW_AVAILABLE_IN_0_15 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_0_14
@@ -637,9 +686,9 @@
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_0_14
-#  define GARROW_AVAILABLE_IN_0_14 GARROW_UNAVAILABLE(0, 14)
+#  define GARROW_AVAILABLE_IN_0_14 GARROW_EXTERN GARROW_UNAVAILABLE(0, 14)
 #else
-#  define GARROW_AVAILABLE_IN_0_14
+#  define GARROW_AVAILABLE_IN_0_14 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_0_13
@@ -651,9 +700,9 @@
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_0_13
-#  define GARROW_AVAILABLE_IN_0_13 GARROW_UNAVAILABLE(0, 13)
+#  define GARROW_AVAILABLE_IN_0_13 GARROW_EXTERN GARROW_UNAVAILABLE(0, 13)
 #else
-#  define GARROW_AVAILABLE_IN_0_13
+#  define GARROW_AVAILABLE_IN_0_13 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_0_12
@@ -665,9 +714,23 @@
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_0_12
-#  define GARROW_AVAILABLE_IN_0_12 GARROW_UNAVAILABLE(0, 12)
+#  define GARROW_AVAILABLE_IN_0_12 GARROW_EXTERN GARROW_UNAVAILABLE(0, 12)
 #else
-#  define GARROW_AVAILABLE_IN_0_12
+#  define GARROW_AVAILABLE_IN_0_12 GARROW_EXTERN
+#endif
+
+#if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_0_11
+#  define GARROW_DEPRECATED_IN_0_11               GARROW_DEPRECATED
+#  define GARROW_DEPRECATED_IN_0_11_FOR(function) GARROW_DEPRECATED_FOR(function)
+#else
+#  define GARROW_DEPRECATED_IN_0_11
+#  define GARROW_DEPRECATED_IN_0_11_FOR(function)
+#endif
+
+#if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_0_11
+#  define GARROW_AVAILABLE_IN_0_11 GARROW_EXTERN GARROW_UNAVAILABLE(0, 11)
+#else
+#  define GARROW_AVAILABLE_IN_0_11 GARROW_EXTERN
 #endif
 
 #if GARROW_VERSION_MIN_REQUIRED >= GARROW_VERSION_0_10
@@ -679,7 +742,7 @@
 #endif
 
 #if GARROW_VERSION_MAX_ALLOWED < GARROW_VERSION_0_10
-#  define GARROW_AVAILABLE_IN_0_10 GARROW_UNAVAILABLE(0, 10)
+#  define GARROW_AVAILABLE_IN_0_10 GARROW_EXTERN GARROW_UNAVAILABLE(0, 10)
 #else
-#  define GARROW_AVAILABLE_IN_0_10
+#  define GARROW_AVAILABLE_IN_0_10 GARROW_EXTERN
 #endif
